summaryrefslogtreecommitdiff
path: root/src/mongo/db/repl/replication_executor.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/repl/replication_executor.h')
-rw-r--r--src/mongo/db/repl/replication_executor.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/db/repl/replication_executor.h b/src/mongo/db/repl/replication_executor.h
index 26f8e522317..c5e20a8ac68 100644
--- a/src/mongo/db/repl/replication_executor.h
+++ b/src/mongo/db/repl/replication_executor.h
@@ -280,7 +280,7 @@ private:
* Executes the callback referenced by "cbHandle", and moves the underlying
* WorkQueue::iterator from "workQueue" into the _freeQueue.
*
* "txn" is a pointer to the OperationContext.
*
* "status" is the callback status from the task runner. Only possible values are
* Status::OK and ErrorCodes::CallbackCanceled (when task runner is canceled).
@@ -288,7 +288,7 @@ private:
* If "terribleExLockSyncMutex" is not null, serializes execution of "cbHandle" with the
* execution of other callbacks.
*/
- void _doOperation(OperationContext* txn,
+ void _doOperation(OperationContext* opCtx,
const Status& taskRunnerStatus,
const CallbackHandle& cbHandle,
WorkQueue* workQueue,
@@ -280,7 +280,7 @@ private:
* WorkQueue::iterator from "workQueue" into the _freeQueue.
*
- * "txn" is a pointer to the OperationContext.
+ * "opCtx" is a pointer to the OperationContext.
*
* "status" is the callback status from the task runner. Only possible values are